/* CALLY - The Clutter Accessibility Implementation Library
 *
 * Copyright (C) 2008 Igalia, S.L.
 *
 * Author: Alejandro Piñeiro Iglesias <apinheiro@igalia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CALLY_H__
#define __CALLY_H__

#define __CALLY_H_INSIDE__

#include "cally-actor.h"
#include "cally-clone.h"
#include "cally-factory.h"
#include "cally-main.h"
#include "cally-root.h"
#include "cally-stage.h"
#include "cally-text.h"
#include "cally-util.h"

#undef __CALLY_H_INSIDE__

#endif /* __CALLY_H__ */
