/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOXED (../mutter-42.5/clutter/clutter/clutter-marshal.list:1) */
extern
void _clutter_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__BOXEDv (GClosure *closure,
                                       GValue   *return_value,
                                       gpointer  instance,
                                       va_list   args,
                                       gpointer  marshal_data,
                                       int       n_params,
                                       GType    *param_types);

/* BOOLEAN:BOXED,INT,INT (../mutter-42.5/clutter/clutter/clutter-marshal.list:2) */
extern
void _clutter_marshal_BOOLEAN__BOXED_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__BOXED_INT_INTv (GClosure *closure,
                                               GValue   *return_value,
                                               gpointer  instance,
                                               va_list   args,
                                               gpointer  marshal_data,
                                               int       n_params,
                                               GType    *param_types);

/* BOOLEAN:OBJECT,BOOLEAN (../mutter-42.5/clutter/clutter/clutter-marshal.list:3) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_BOOLEANv (GClosure *closure,
                                                GValue   *return_value,
                                                gpointer  instance,
                                                va_list   args,
                                                gpointer  marshal_data,
                                                int       n_params,
                                                GType    *param_types);

/* BOOLEAN:OBJECT,BOXED (../mutter-42.5/clutter/clutter/clutter-marshal.list:4) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_BOXEDv (GClosure *closure,
                                              GValue   *return_value,
                                              gpointer  instance,
                                              va_list   args,
                                              gpointer  marshal_data,
                                              int       n_params,
                                              GType    *param_types);

/* BOOLEAN:OBJECT,BOXED,DOUBLE (../mutter-42.5/clutter/clutter/clutter-marshal.list:5) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_BOXED_DOUBLE (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_BOXED_DOUBLEv (GClosure *closure,
                                                     GValue   *return_value,
                                                     gpointer  instance,
                                                     va_list   args,
                                                     gpointer  marshal_data,
                                                     int       n_params,
                                                     GType    *param_types);

/* BOOLEAN:OBJECT,DOUBLE (../mutter-42.5/clutter/clutter/clutter-marshal.list:6) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_DOUBLEv (GClosure *closure,
                                               GValue   *return_value,
                                               gpointer  instance,
                                               va_list   args,
                                               gpointer  marshal_data,
                                               int       n_params,
                                               GType    *param_types);

/* BOOLEAN:OBJECT,ENUM (../mutter-42.5/clutter/clutter/clutter-marshal.list:7) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_ENUM (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_ENUMv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* BOOLEAN:OBJECT,FLAGS (../mutter-42.5/clutter/clutter/clutter-marshal.list:8) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_FLAGS (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_FLAGSv (GClosure *closure,
                                              GValue   *return_value,
                                              gpointer  instance,
                                              va_list   args,
                                              gpointer  marshal_data,
                                              int       n_params,
                                              GType    *param_types);

/* BOOLEAN:STRING,UINT,FLAGS (../mutter-42.5/clutter/clutter/clutter-marshal.list:9) */
extern
void _clutter_marshal_BOOLEAN__STRING_UINT_FLAGS (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__STRING_UINT_FLAGSv (GClosure *closure,
                                                   GValue   *return_value,
                                                   gpointer  instance,
                                                   va_list   args,
                                                   gpointer  marshal_data,
                                                   int       n_params,
                                                   GType    *param_types);

/* BOOLEAN:OBJECT (../mutter-42.5/clutter/clutter/clutter-marshal.list:10) */
extern
void _clutter_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECTv (GClosure *closure,
                                        GValue   *return_value,
                                        gpointer  instance,
                                        va_list   args,
                                        gpointer  marshal_data,
                                        int       n_params,
                                        GType    *param_types);

/* BOOLEAN:OBJECT,FLOAT,FLOAT (../mutter-42.5/clutter/clutter/clutter-marshal.list:11) */
extern
void _clutter_marshal_BOOLEAN__OBJECT_FLOAT_FLOAT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
extern
void _clutter_marshal_BOOLEAN__OBJECT_FLOAT_FLOATv (GClosure *closure,
                                                    GValue   *return_value,
                                                    gpointer  instance,
                                                    va_list   args,
                                                    gpointer  marshal_data,
                                                    int       n_params,
                                                    GType    *param_types);

/* BOXED:UINT,UINT (../mutter-42.5/clutter/clutter/clutter-marshal.list:12) */
extern
void _clutter_marshal_BOXED__UINT_UINT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _clutter_marshal_BOXED__UINT_UINTv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* DOUBLE:VOID (../mutter-42.5/clutter/clutter/clutter-marshal.list:13) */
extern
void _clutter_marshal_DOUBLE__VOID (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);
extern
void _clutter_marshal_DOUBLE__VOIDv (GClosure *closure,
                                     GValue   *return_value,
                                     gpointer  instance,
                                     va_list   args,
                                     gpointer  marshal_data,
                                     int       n_params,
                                     GType    *param_types);

/* UINT:VOID (../mutter-42.5/clutter/clutter/clutter-marshal.list:14) */
extern
void _clutter_marshal_UINT__VOID (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);
extern
void _clutter_marshal_UINT__VOIDv (GClosure *closure,
                                   GValue   *return_value,
                                   gpointer  instance,
                                   va_list   args,
                                   gpointer  marshal_data,
                                   int       n_params,
                                   GType    *param_types);

/* VOID:BOXED,FLAGS (../mutter-42.5/clutter/clutter/clutter-marshal.list:15) */
extern
void _clutter_marshal_VOID__BOXED_FLAGS (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _clutter_marshal_VOID__BOXED_FLAGSv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* VOID:INT64,INT64,FLOAT,BOOLEAN (../mutter-42.5/clutter/clutter/clutter-marshal.list:16) */
extern
void _clutter_marshal_VOID__INT64_INT64_FLOAT_BOOLEAN (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
extern
void _clutter_marshal_VOID__INT64_INT64_FLOAT_BOOLEANv (GClosure *closure,
                                                        GValue   *return_value,
                                                        gpointer  instance,
                                                        va_list   args,
                                                        gpointer  marshal_data,
                                                        int       n_params,
                                                        GType    *param_types);

/* VOID:INT,INT (../mutter-42.5/clutter/clutter/clutter-marshal.list:17) */
extern
void _clutter_marshal_VOID__INT_INT (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
extern
void _clutter_marshal_VOID__INT_INTv (GClosure *closure,
                                      GValue   *return_value,
                                      gpointer  instance,
                                      va_list   args,
                                      gpointer  marshal_data,
                                      int       n_params,
                                      GType    *param_types);

/* VOID:INT,POINTER (../mutter-42.5/clutter/clutter/clutter-marshal.list:18) */
extern
void _clutter_marshal_VOID__INT_POINTER (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _clutter_marshal_VOID__INT_POINTERv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* VOID:FLOAT,FLOAT (../mutter-42.5/clutter/clutter/clutter-marshal.list:19) */
extern
void _clutter_marshal_VOID__FLOAT_FLOAT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _clutter_marshal_VOID__FLOAT_FLOATv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* VOID:INT,INT,INT,INT (../mutter-42.5/clutter/clutter/clutter-marshal.list:20) */
extern
void _clutter_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
extern
void _clutter_marshal_VOID__INT_INT_INT_INTv (GClosure *closure,
                                              GValue   *return_value,
                                              gpointer  instance,
                                              va_list   args,
                                              gpointer  marshal_data,
                                              int       n_params,
                                              GType    *param_types);

/* VOID:OBJECT,FLAGS (../mutter-42.5/clutter/clutter/clutter-marshal.list:21) */
extern
void _clutter_marshal_VOID__OBJECT_FLAGS (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_FLAGSv (GClosure *closure,
                                           GValue   *return_value,
                                           gpointer  instance,
                                           va_list   args,
                                           gpointer  marshal_data,
                                           int       n_params,
                                           GType    *param_types);

/* VOID:OBJECT,FLAGS,BOOLEAN (../mutter-42.5/clutter/clutter/clutter-marshal.list:22) */
extern
void _clutter_marshal_VOID__OBJECT_FLAGS_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_FLAGS_BOOLEANv (GClosure *closure,
                                                   GValue   *return_value,
                                                   gpointer  instance,
                                                   va_list   args,
                                                   gpointer  marshal_data,
                                                   int       n_params,
                                                   GType    *param_types);

/* VOID:OBJECT,FLAGS,UINT (../mutter-42.5/clutter/clutter/clutter-marshal.list:23) */
extern
void _clutter_marshal_VOID__OBJECT_FLAGS_UINT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_FLAGS_UINTv (GClosure *closure,
                                                GValue   *return_value,
                                                gpointer  instance,
                                                va_list   args,
                                                gpointer  marshal_data,
                                                int       n_params,
                                                GType    *param_types);

/* VOID:OBJECT,FLOAT,FLOAT (../mutter-42.5/clutter/clutter/clutter-marshal.list:24) */
extern
void _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_FLOAT_FLOATv (GClosure *closure,
                                                 GValue   *return_value,
                                                 gpointer  instance,
                                                 va_list   args,
                                                 gpointer  marshal_data,
                                                 int       n_params,
                                                 GType    *param_types);

/* VOID:OBJECT,FLOAT,FLOAT,FLAGS (../mutter-42.5/clutter/clutter/clutter-marshal.list:25) */
extern
void _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_FLAGS (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_FLOAT_FLOAT_FLAGSv (GClosure *closure,
                                                       GValue   *return_value,
                                                       gpointer  instance,
                                                       va_list   args,
                                                       gpointer  marshal_data,
                                                       int       n_params,
                                                       GType    *param_types);

/* VOID:OBJECT,OBJECT (../mutter-42.5/clutter/clutter/clutter-marshal.list:26) */
extern
void _clutter_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_OBJECTv (GClosure *closure,
                                            GValue   *return_value,
                                            gpointer  instance,
                                            va_list   args,
                                            gpointer  marshal_data,
                                            int       n_params,
                                            GType    *param_types);

/* VOID:OBJECT,PARAM (../mutter-42.5/clutter/clutter/clutter-marshal.list:27) */
extern
void _clutter_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_PARAMv (GClosure *closure,
                                           GValue   *return_value,
                                           gpointer  instance,
                                           va_list   args,
                                           gpointer  marshal_data,
                                           int       n_params,
                                           GType    *param_types);

/* VOID:OBJECT,POINTER (../mutter-42.5/clutter/clutter/clutter-marshal.list:28) */
extern
void _clutter_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_POINTERv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* VOID:OBJECT,UINT (../mutter-42.5/clutter/clutter/clutter-marshal.list:29) */
extern
void _clutter_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _clutter_marshal_VOID__OBJECT_UINTv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* VOID:STRING,BOOLEAN (../mutter-42.5/clutter/clutter/clutter-marshal.list:30) */
extern
void _clutter_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _clutter_marshal_VOID__STRING_BOOLEANv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* VOID:STRING,BOOLEAN,BOOLEAN (../mutter-42.5/clutter/clutter/clutter-marshal.list:31) */
extern
void _clutter_marshal_VOID__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
extern
void _clutter_marshal_VOID__STRING_BOOLEAN_BOOLEANv (GClosure *closure,
                                                     GValue   *return_value,
                                                     gpointer  instance,
                                                     va_list   args,
                                                     gpointer  marshal_data,
                                                     int       n_params,
                                                     GType    *param_types);

/* VOID:STRING,INT (../mutter-42.5/clutter/clutter/clutter-marshal.list:32) */
extern
void _clutter_marshal_VOID__STRING_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _clutter_marshal_VOID__STRING_INTv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* VOID:UINT,STRING,UINT (../mutter-42.5/clutter/clutter/clutter-marshal.list:33) */
extern
void _clutter_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
extern
void _clutter_marshal_VOID__UINT_STRING_UINTv (GClosure *closure,
                                               GValue   *return_value,
                                               gpointer  instance,
                                               va_list   args,
                                               gpointer  marshal_data,
                                               int       n_params,
                                               GType    *param_types);

/* VOID:UINT,UINT (../mutter-42.5/clutter/clutter/clutter-marshal.list:34) */
extern
void _clutter_marshal_VOID__UINT_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
extern
void _clutter_marshal_VOID__UINT_UINTv (GClosure *closure,
                                        GValue   *return_value,
                                        gpointer  instance,
                                        va_list   args,
                                        gpointer  marshal_data,
                                        int       n_params,
                                        GType    *param_types);

/* VOID:STRING,INT,POINTER (../mutter-42.5/clutter/clutter/clutter-marshal.list:35) */
extern
void _clutter_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
extern
void _clutter_marshal_VOID__STRING_INT_POINTERv (GClosure *closure,
                                                 GValue   *return_value,
                                                 gpointer  instance,
                                                 va_list   args,
                                                 gpointer  marshal_data,
                                                 int       n_params,
                                                 GType    *param_types);


G_END_DECLS
