
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __CLUTTER_ENUM_TYPES_H__
#define __CLUTTER_ENUM_TYPES_H__

#if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
#error "Only <clutter/clutter.h> can be included directly."
#endif

#include <clutter/clutter-types.h>

G_BEGIN_DECLS
/* enumerations from "clutter-enums.h" */
CLUTTER_EXPORT GType clutter_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRAVITY (clutter_gravity_get_type())
CLUTTER_EXPORT GType clutter_rotate_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_AXIS (clutter_rotate_axis_get_type())
CLUTTER_EXPORT GType clutter_rotate_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_DIRECTION (clutter_rotate_direction_get_type())
CLUTTER_EXPORT GType clutter_request_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REQUEST_MODE (clutter_request_mode_get_type())
CLUTTER_EXPORT GType clutter_animation_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ANIMATION_MODE (clutter_animation_mode_get_type())
CLUTTER_EXPORT GType clutter_text_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXT_DIRECTION (clutter_text_direction_get_type())
CLUTTER_EXPORT GType clutter_shader_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_TYPE (clutter_shader_type_get_type())
CLUTTER_EXPORT GType clutter_modifier_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_MODIFIER_TYPE (clutter_modifier_type_get_type())
CLUTTER_EXPORT GType clutter_pointer_a11y_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_POINTER_A11Y_FLAGS (clutter_pointer_a11y_flags_get_type())
CLUTTER_EXPORT GType clutter_pointer_a11y_dwell_click_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_POINTER_A11Y_DWELL_CLICK_TYPE (clutter_pointer_a11y_dwell_click_type_get_type())
CLUTTER_EXPORT GType clutter_pointer_a11y_dwell_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_POINTER_A11Y_DWELL_DIRECTION (clutter_pointer_a11y_dwell_direction_get_type())
CLUTTER_EXPORT GType clutter_pointer_a11y_dwell_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_POINTER_A11Y_DWELL_MODE (clutter_pointer_a11y_dwell_mode_get_type())
CLUTTER_EXPORT GType clutter_pointer_a11y_timeout_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_POINTER_A11Y_TIMEOUT_TYPE (clutter_pointer_a11y_timeout_type_get_type())
CLUTTER_EXPORT GType clutter_actor_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_FLAGS (clutter_actor_flags_get_type())
CLUTTER_EXPORT GType clutter_offscreen_redirect_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_OFFSCREEN_REDIRECT (clutter_offscreen_redirect_get_type())
CLUTTER_EXPORT GType clutter_align_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ALIGN_AXIS (clutter_align_axis_get_type())
CLUTTER_EXPORT GType clutter_interpolation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INTERPOLATION (clutter_interpolation_get_type())
CLUTTER_EXPORT GType clutter_bin_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BIN_ALIGNMENT (clutter_bin_alignment_get_type())
CLUTTER_EXPORT GType clutter_bind_coordinate_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BIND_COORDINATE (clutter_bind_coordinate_get_type())
CLUTTER_EXPORT GType clutter_effect_paint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EFFECT_PAINT_FLAGS (clutter_effect_paint_flags_get_type())
CLUTTER_EXPORT GType clutter_box_alignment_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BOX_ALIGNMENT (clutter_box_alignment_get_type())
CLUTTER_EXPORT GType clutter_long_press_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_LONG_PRESS_STATE (clutter_long_press_state_get_type())
CLUTTER_EXPORT GType clutter_static_color_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STATIC_COLOR (clutter_static_color_get_type())
CLUTTER_EXPORT GType clutter_drag_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_DRAG_AXIS (clutter_drag_axis_get_type())
CLUTTER_EXPORT GType clutter_event_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_FLAGS (clutter_event_flags_get_type())
CLUTTER_EXPORT GType clutter_event_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_TYPE (clutter_event_type_get_type())
CLUTTER_EXPORT GType clutter_scroll_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_DIRECTION (clutter_scroll_direction_get_type())
CLUTTER_EXPORT GType clutter_feature_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FEATURE_FLAGS (clutter_feature_flags_get_type())
CLUTTER_EXPORT GType clutter_flow_orientation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FLOW_ORIENTATION (clutter_flow_orientation_get_type())
CLUTTER_EXPORT GType clutter_input_capabilities_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_CAPABILITIES (clutter_input_capabilities_get_type())
CLUTTER_EXPORT GType clutter_input_device_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_DEVICE_TYPE (clutter_input_device_type_get_type())
CLUTTER_EXPORT GType clutter_input_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_MODE (clutter_input_mode_get_type())
CLUTTER_EXPORT GType clutter_input_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_AXIS (clutter_input_axis_get_type())
CLUTTER_EXPORT GType clutter_input_axis_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_AXIS_FLAGS (clutter_input_axis_flags_get_type())
CLUTTER_EXPORT GType clutter_snap_edge_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SNAP_EDGE (clutter_snap_edge_get_type())
CLUTTER_EXPORT GType clutter_pick_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PICK_MODE (clutter_pick_mode_get_type())
CLUTTER_EXPORT GType clutter_swipe_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SWIPE_DIRECTION (clutter_swipe_direction_get_type())
CLUTTER_EXPORT GType clutter_pan_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PAN_AXIS (clutter_pan_axis_get_type())
CLUTTER_EXPORT GType clutter_texture_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_FLAGS (clutter_texture_flags_get_type())
CLUTTER_EXPORT GType clutter_texture_quality_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_QUALITY (clutter_texture_quality_get_type())
CLUTTER_EXPORT GType clutter_timeline_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TIMELINE_DIRECTION (clutter_timeline_direction_get_type())
CLUTTER_EXPORT GType clutter_unit_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_UNIT_TYPE (clutter_unit_type_get_type())
CLUTTER_EXPORT GType clutter_path_node_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PATH_NODE_TYPE (clutter_path_node_type_get_type())
CLUTTER_EXPORT GType clutter_actor_align_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_ALIGN (clutter_actor_align_get_type())
CLUTTER_EXPORT GType clutter_repaint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REPAINT_FLAGS (clutter_repaint_flags_get_type())
CLUTTER_EXPORT GType clutter_content_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_CONTENT_GRAVITY (clutter_content_gravity_get_type())
CLUTTER_EXPORT GType clutter_scaling_filter_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCALING_FILTER (clutter_scaling_filter_get_type())
CLUTTER_EXPORT GType clutter_orientation_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ORIENTATION (clutter_orientation_get_type())
CLUTTER_EXPORT GType clutter_scroll_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_MODE (clutter_scroll_mode_get_type())
CLUTTER_EXPORT GType clutter_grid_position_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRID_POSITION (clutter_grid_position_get_type())
CLUTTER_EXPORT GType clutter_content_repeat_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_CONTENT_REPEAT (clutter_content_repeat_get_type())
CLUTTER_EXPORT GType clutter_step_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STEP_MODE (clutter_step_mode_get_type())
CLUTTER_EXPORT GType clutter_gesture_trigger_edge_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GESTURE_TRIGGER_EDGE (clutter_gesture_trigger_edge_get_type())
CLUTTER_EXPORT GType clutter_touchpad_gesture_phase_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TOUCHPAD_GESTURE_PHASE (clutter_touchpad_gesture_phase_get_type())
CLUTTER_EXPORT GType clutter_scroll_source_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_SOURCE (clutter_scroll_source_get_type())
CLUTTER_EXPORT GType clutter_scroll_finish_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_FINISH_FLAGS (clutter_scroll_finish_flags_get_type())
CLUTTER_EXPORT GType clutter_input_device_tool_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_DEVICE_TOOL_TYPE (clutter_input_device_tool_type_get_type())
CLUTTER_EXPORT GType clutter_input_device_pad_source_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_DEVICE_PAD_SOURCE (clutter_input_device_pad_source_get_type())
CLUTTER_EXPORT GType clutter_input_device_pad_feature_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_DEVICE_PAD_FEATURE (clutter_input_device_pad_feature_get_type())
CLUTTER_EXPORT GType clutter_input_content_hint_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_CONTENT_HINT_FLAGS (clutter_input_content_hint_flags_get_type())
CLUTTER_EXPORT GType clutter_input_content_purpose_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_CONTENT_PURPOSE (clutter_input_content_purpose_get_type())
CLUTTER_EXPORT GType clutter_input_panel_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INPUT_PANEL_STATE (clutter_input_panel_state_get_type())
CLUTTER_EXPORT GType clutter_preedit_reset_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PREEDIT_RESET_MODE (clutter_preedit_reset_mode_get_type())
CLUTTER_EXPORT GType clutter_event_phase_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_PHASE (clutter_event_phase_get_type())
CLUTTER_EXPORT GType clutter_grab_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRAB_STATE (clutter_grab_state_get_type())
/* enumerations from "clutter-frame-clock.h" */
CLUTTER_EXPORT GType clutter_frame_result_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FRAME_RESULT (clutter_frame_result_get_type())
/* enumerations from "clutter-image.h" */
CLUTTER_EXPORT GType clutter_image_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_IMAGE_ERROR (clutter_image_error_get_type())
/* enumerations from "clutter-main.h" */
CLUTTER_EXPORT GType clutter_debug_flag_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_DEBUG_FLAG (clutter_debug_flag_get_type())
CLUTTER_EXPORT GType clutter_pick_debug_flag_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PICK_DEBUG_FLAG (clutter_pick_debug_flag_get_type())
CLUTTER_EXPORT GType clutter_draw_debug_flag_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_DRAW_DEBUG_FLAG (clutter_draw_debug_flag_get_type())
/* enumerations from "clutter-paint-context.h" */
CLUTTER_EXPORT GType clutter_paint_flag_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PAINT_FLAG (clutter_paint_flag_get_type())
/* enumerations from "clutter-script.h" */
CLUTTER_EXPORT GType clutter_script_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCRIPT_ERROR (clutter_script_error_get_type())
/* enumerations from "clutter-seat.h" */
CLUTTER_EXPORT GType clutter_virtual_device_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_VIRTUAL_DEVICE_TYPE (clutter_virtual_device_type_get_type())
/* enumerations from "clutter-stage.h" */
CLUTTER_EXPORT GType clutter_frame_info_flag_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FRAME_INFO_FLAG (clutter_frame_info_flag_get_type())
/* enumerations from "clutter-virtual-input-device.h" */
CLUTTER_EXPORT GType clutter_button_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_BUTTON_STATE (clutter_button_state_get_type())
CLUTTER_EXPORT GType clutter_key_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_KEY_STATE (clutter_key_state_get_type())
G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */

